@@ -64,9 +64,6 @@ PlaylistSplitter::PlaylistSplitter(PlayerManager *player, QWidget *parent) :
 
     m_editor->slotUpdateCollection();
     m_editor->setupObservers();
-
-    connect(m_player, SIGNAL(signalItemChanged(FileHandle)),
-            this,     SIGNAL(playingItemChanged(FileHandle)));
 }
 
 PlaylistSplitter::~PlaylistSplitter()
@@ -194,7 +191,7 @@ void PlaylistSplitter::setupLayout()
 
     // Create the PlaylistBox
 
-    m_playlistBox = new PlaylistBox(this, m_playlistStack);
+    m_playlistBox = new PlaylistBox(m_player, this, m_playlistStack);
     m_playlistBox->setObjectName( "playlistBox" );
 
     connect(m_playlistBox->object(), SIGNAL(signalSelectedItemsChanged()),
