@@ -23,6 +23,7 @@
 
 //KMix
 class Mixer;
+class MixSet;
 #include "volume.h"
 
 // KDE
@@ -99,9 +100,12 @@ public:
     *  @par name is the readable name. This one is presented to the user in the GUI
     *  @par type The control type. It is only used to find an appropriate icon
     */
-   MixDevice( Mixer* mixer, const QString& id, const QString& name, ChannelType type = UNKNOWN );
+   MixDevice( Mixer* mixer, const QString& id, const QString& name, ChannelType type );
+   MixDevice( Mixer* mixer, const QString& id, const QString& name, const QString& iconName = "", bool doNotRestore = false, MixSet* moveDestinationMixSet = 0 );
    ~MixDevice();
 
+   const QString& iconName() const { return _iconName; }
+
    void addPlaybackVolume(Volume &playbackVol);
    void addCaptureVolume (Volume &captureVol);
    void addEnums (QList<QString*>& ref_enumList);
@@ -134,6 +138,8 @@ public:
 
    bool isEnum()                   { return ( ! _enumValues.empty() ); }
 
+   bool isMovable()                { return (0 != _moveDestinationMixSet); }
+   MixSet *getMoveDestinationMixSet() { return _moveDestinationMixSet; }
 
    Volume& playbackVolume();
    Volume& captureVolume();
@@ -145,8 +151,6 @@ public:
    virtual void read( KConfig *config, const QString& grp );
    virtual void write( KConfig *config, const QString& grp );
 
-   ChannelType type() { return _type; }
-
 private:
    Mixer *_mixer;
    Volume _playbackVolume;
@@ -154,13 +158,16 @@ private:
    int _enumCurrentId;
    QList<QString> _enumValues; // A MixDevice, that is an ENUM, has these _enumValues
 
-   ChannelType _type;
+   bool _doNotRestore;
+   MixSet *_moveDestinationMixSet;
+   QString _iconName;
 
    QString _name;   // Channel name
    QString _id;     // Primary key, used as part in config file keys
 
-   void readPlaybackOrCapture(const KConfigGroup& config, const char* nameLeftVolume, const char* nameRightVolume, bool capture);
-   void writePlaybackOrCapture(KConfigGroup& config, const char* nameLeftVolume, const char* nameRightVolume, bool capture);
+   void init( Mixer* mixer, const QString& id, const QString& name, const QString& iconName, bool doNotRestore, MixSet* moveDestinationMixSet );
+   void readPlaybackOrCapture(const KConfigGroup& config, bool capture);
+   void writePlaybackOrCapture(KConfigGroup& config, bool capture);
 
 };
 
